@@ -9,7 +9,7 @@ import os
 import re
 from knack.util import CLIError
 from knack.log import get_logger
-from azure.cli.core.azclierror import InvalidArgumentValueError
+from azure.cli.core.azclierror import InvalidArgumentValueError, RequiredArgumentMissingError
 from azure.cli.core.util import user_confirmation
 from ._constants import get_managed_sku, get_premium_sku
 from ._utils import (
@@ -26,14 +26,26 @@ logger = get_logger(__name__)
 DEF_DIAG_SETTINGS_NAME_TEMPLATE = '{}-diagnostic-settings'
 SYSTEM_ASSIGNED_IDENTITY_ALIAS = '[system]'
 DENY_ACTION = 'Deny'
+DOMAIN_NAME_LABEL_SCOPE_UNSECURE = 'Unsecure'
+DOMAIN_NAME_LABEL_SCOPE_RESOURCE_GROUP_REUSE = 'ResourceGroupReuse'
 
 
-def acr_check_name(client, registry_name):
-    registry = {
-        'name': registry_name,
-        'type': 'Microsoft.ContainerRegistry/registries'
-    }
-    return client.check_name_availability(registry)
+def acr_check_name(cmd, client, registry_name, resource_group_name=None, dnl_scope=DOMAIN_NAME_LABEL_SCOPE_UNSECURE):
+    if dnl_scope.lower() == DOMAIN_NAME_LABEL_SCOPE_RESOURCE_GROUP_REUSE.lower() and resource_group_name is None:
+        raise RequiredArgumentMissingError("Resource group name is required for domain name label scope " +
+                                           DOMAIN_NAME_LABEL_SCOPE_RESOURCE_GROUP_REUSE)
+    domain_name_label_scope = _get_domain_name_label_scope(cmd, dnl_scope)
+    if domain_name_label_scope:
+        RegistryNameCheckRequest = cmd.get_models('RegistryNameCheckRequest')
+        registry_check_name_request = RegistryNameCheckRequest(
+            name=registry_name,
+            type='Microsoft.ContainerRegistry/registries',
+            resource_group_name=resource_group_name,
+            auto_generated_domain_name_label_scope=domain_name_label_scope)
+    else:
+        raise RequiredArgumentMissingError("Invalid domain name label scope. The allowed values are 'Unsecure'," +
+                                           " 'TenantReuse', 'SubscriptionReuse', 'ResourceGroupReuse' or 'NoReuse'.")
+    return client.check_name_availability(registry_check_name_request)
 
 
 def acr_list(client, resource_group_name=None):
@@ -58,7 +70,8 @@ def acr_create(cmd,
                allow_trusted_services=None,
                allow_exports=None,
                tags=None,
-               allow_metadata_search=None):
+               allow_metadata_search=None,
+               dnl_scope=None):
 
     if default_action and sku not in get_premium_sku(cmd):
         raise CLIError(NETWORK_RULE_NOT_SUPPORTED)
@@ -87,6 +100,9 @@ def acr_create(cmd,
     if allow_metadata_search is not None:
         _configure_metadata_search(cmd, registry, allow_metadata_search)
 
+    if dnl_scope is not None:
+        _configure_domain_name_label_scope(cmd, registry, dnl_scope)
+
     _handle_network_bypass(cmd, registry, allow_trusted_services)
     _handle_export_policy(cmd, registry, allow_exports)
 
@@ -630,3 +646,13 @@ def list_private_link_resources(cmd, client, registry_name, resource_group_name=
 def _configure_metadata_search(cmd, registry, enabled):
     MetadataSearch = cmd.get_models('MetadataSearch')
     registry.metadata_search = (MetadataSearch.enabled if enabled else MetadataSearch.disabled)
+
+
+def _configure_domain_name_label_scope(cmd, registry, scope):
+    registry.auto_generated_domain_name_label_scope = _get_domain_name_label_scope(cmd, scope)
+
+
+def _get_domain_name_label_scope(cmd, scope):
+    if DomainNameLabelScope := cmd.get_models('AutoGeneratedDomainNameLabelScope'):
+        return DomainNameLabelScope(scope).value
+    return DOMAIN_NAME_LABEL_SCOPE_UNSECURE
