@@ -118,18 +118,18 @@ def get_key_vault_base_url(cli_ctx, vault_name):
 
 
 def list_sku_info(cli_ctx, location=None):
-    from ._client_factory import _compute_client_factory
+    _ListSkus = import_aaz_by_profile(cli_ctx.cloud.profile, 'vm').ListSkus
 
     def _match_location(loc, locations):
-        return next((x for x in locations if x.lower() == loc.lower()), None)
+        return next((x for x in locations if str(x).lower() == str(loc).lower()), None)
 
-    client = _compute_client_factory(cli_ctx)
-    result = client.resource_skus.list()
+    result = _ListSkus(cli_ctx=cli_ctx)(command_args={})
     if location:
-        result = [r for r in result if _match_location(location, r.locations)]
+        result = [r for r in result if _match_location(location, r['locations'])]
     return result
 
 
+# pylint: disable=line-too-long
 def is_sku_available(cmd, sku_info, zone):
     """
     The SKU is unavailable in the following cases:
@@ -140,19 +140,19 @@ def is_sku_available(cmd, sku_info, zone):
     is_available = True
     is_restrict_zone = False
     is_restrict_location = False
-    if not sku_info.restrictions:
+    if not sku_info.get('restrictions', []):
         return is_available
-    for restriction in sku_info.restrictions:
-        if restriction.reason_code == 'NotAvailableForSubscription':
+    for restriction in sku_info['restrictions']:
+        if restriction.get('reason_code', '') == 'NotAvailableForSubscription':
             # The attribute location_info is not supported in versions 2017-03-30 and earlier
             if cmd.supported_api_version(max_api='2017-03-30'):
                 is_available = False
                 break
-            if restriction.type == 'Zone' and not (
-                    set(sku_info.location_info[0].zones or []) - set(restriction.restriction_info.zones or [])):
+            if restriction['type'] == 'Zone' and not (
+                    set(sku_info['location_info'][0].get('zones', []) or []) - set(restriction['restriction_info'].get('zones', []) or [])):
                 is_restrict_zone = True
-            if restriction.type == 'Location' and (
-                    sku_info.location_info[0].location in (restriction.restriction_info.locations or [])):
+            if restriction['type'] == 'Location' and (
+                    sku_info['location_info'][0]['location'] in (restriction['restriction_info'].get('locations', []) or [])):
                 is_restrict_location = True
 
             if is_restrict_location or (is_restrict_zone and zone):
